#!/usr/bin/env python
# -*- coding: utf-8 -*-
import argparse
from googletrans import Translator


def main():
    parser = argparse.ArgumentParser(
        description='Python Google Translator as a command-line tool')
    parser.add_argument('text', help='The text you want to translate.')
    parser.add_argument('-d', '--dest', default='en',
                        help='The destination language you want to translate. (Default: en)')
    parser.add_argument('-s', '--src', default='auto',
                        help='The source language you want to translate. (Default: auto)')
    parser.add_argument('-c', '--detect', action='store_true', default=False,
                        help='')
    args = parser.parse_args()
    translator = Translator()

    if args.detect:
        result = translator.detect(args.text)
        result = """
        [{lang}, {confidence}] {text}
        """.strip().format(text=args.text,
                           lang=result.lang, confidence=result.confidence)
        print(result)
        return

    result = translator.translate(args.text, dest=args.dest, src=args.src)
    result = u"""
[{src}] {original}
    ->
[{dest}] {text}
[pron.] {pronunciation}
    """.strip().format(src=result.src, dest=result.dest, original=result.origin,
                       text=result.text, pronunciation=result.pronunciation)
    print(result)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['googletrans']

package_data = \
{'': ['*']}

install_requires = \
['coveralls>=2.0.0,<3.0.0', 'requests>=2.23.0,<3.0.0']

entry_points = \
{'console_scripts': ['translate = googletrans.cli:main']}

setup_kwargs = {
    'name': 'py-googletrans-html',
    'version': '2.4.1',
    'description': 'Free Google Translate API for Python. Translates totally free of charge.',
    'long_description': 'Googletrans\n===========\n\n|GitHub license| |travis status| |Documentation Status| |PyPI version|\n|Coverage Status| |Code Climate|\n\nGoogletrans is a **free** and **unlimited** python library that\nimplemented Google Translate API. This uses the `Google Translate Ajax\nAPI <https://translate.google.com>`__ to make calls to such methods as\ndetect and translate.\n\nCompatible with Python 2.7+ and 3.4+. (Note: Python 2 support will be dropped in the\nnext major release.)\n\nFor details refer to the `API\nDocumentation <https://py-googletrans.readthedocs.io/en/latest>`__.\n\nFeatures\n--------\n\n-  Fast and reliable - it uses the same servers that\n   translate.google.com uses\n-  Auto language detection\n-  Bulk translations\n-  Customizable service URL\n-  Connection pooling (the advantage of using requests.Session)\n-  HTTP/2 support\n\nTODO\n~~~~\n\nmore features are coming soon.\n\n-  Proxy support\n-  Internal session management (for better bulk translations)\n\nHTTP/2 support\n~~~~~~~~~~~~~~\n\nThis is a great deal for everyone! (up to 2x times faster in my test) If\nyou want to get googletrans faster you should install\n`hyper <https://github.com/Lukasa/hyper>`__ package. Googletrans will\nautomatically detect if hyper is installed and if so, it will be used\nfor http networking.\n\nHow does this library work\n~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nYou may wonder why this library works properly, whereas other\napproaches such like goslate won\'t work since Google has updated its\ntranslation service recently with a ticket mechanism to prevent a lot of\ncrawler programs.\n\nI eventually figure out a way to generate a ticket by reverse\nengineering on the `obfuscated and minified code used by Google to\ngenerate such\ntoken <https://translate.google.com/translate/releases/twsfe_w_20170306_RC00/r/js/desktop_module_main.js>`__,\nand implemented on the top of Python. However, this could be blocked at\nany time.\n\n--------------\n\nInstallation\n------------\n\nTo install, either use things like pip with the package "googletrans"\nor download the package and put the "googletrans" directory into your\npython path. Anyway, it is noteworthy that, this just requires two\nmodules: requests and future.\n\n.. code:: bash\n\n    $ pip install googletrans\n\nBasic Usage\n-----------\n\nIf source language is not given, google translate attempts to detect the\nsource language.\n\n.. code:: python\n\n    >>> from googletrans import Translator\n    >>> translator = Translator()\n    >>> translator.translate(\'안녕하세요.\')\n    # <Translated src=ko dest=en text=Good evening. pronunciation=Good evening.>\n    >>> translator.translate(\'안녕하세요.\', dest=\'ja\')\n    # <Translated src=ko dest=ja text=こんにちは。 pronunciation=Kon\'nichiwa.>\n    >>> translator.translate(\'veritas lux mea\', src=\'la\')\n    # <Translated src=la dest=en text=The truth is my light pronunciation=The truth is my light>\n\nCustomize service URL\n~~~~~~~~~~~~~~~~~~~~~\n\nYou can use another google translate domain for translation. If multiple\nURLs are provided it then randomly chooses a domain.\n\n.. code:: python\n\n    >>> from googletrans import Translator\n    >>> translator = Translator(service_urls=[\n          \'translate.google.com\',\n          \'translate.google.co.kr\',\n        ])\n\nAdvanced Usage (Bulk)\n~~~~~~~~~~~~~~~~~~~~~\n\nArray can be used to translate a batch of strings in a single method\ncall and a single HTTP session. The exact same method shown above work\nfor arrays as well.\n\n.. code:: python\n\n    >>> translations = translator.translate([\'The quick brown fox\', \'jumps over\', \'the lazy dog\'], dest=\'ko\')\n    >>> for translation in translations:\n    ...    print(translation.origin, \' -> \', translation.text)\n    # The quick brown fox  ->  빠른 갈색 여우\n    # jumps over  ->  이상 점프\n    # the lazy dog  ->  게으른 개\n\nLanguage detection\n~~~~~~~~~~~~~~~~~~\n\nThe detect method, as its name implies, identifies the language used in\na given sentence.\n\n.. code:: python\n\n    >>> from googletrans import Translator\n    >>> translator = Translator()\n    >>> translator.detect(\'이 문장은 한글로 쓰여졌습니다.\')\n    # <Detected lang=ko confidence=0.27041003>\n    >>> translator.detect(\'この文章は日本語で書かれました。\')\n    # <Detected lang=ja confidence=0.64889508>\n    >>> translator.detect(\'This sentence is written in English.\')\n    # <Detected lang=en confidence=0.22348526>\n    >>> translator.detect(\'Tiu frazo estas skribita en Esperanto.\')\n    # <Detected lang=eo confidence=0.10538048>\n\nGoogleTrans as a command line application\n-----------------------------------------\n\n.. code:: bash\n\n    $ translate -h\n    usage: translate [-h] [-d DEST] [-s SRC] [-c] text\n\n    Python Google Translator as a command-line tool\n\n    positional arguments:\n      text                  The text you want to translate.\n\n    optional arguments:\n      -h, --help            show this help message and exit\n      -d DEST, --dest DEST  The destination language you want to translate.\n                            (Default: en)\n      -s SRC, --src SRC     The source language you want to translate. (Default:\n                            auto)\n      -c, --detect\n\n    $ translate "veritas lux mea" -s la -d en\n    [veritas] veritas lux mea\n        ->\n    [en] The truth is my light\n    [pron.] The truth is my light\n\n    $ translate -c "안녕하세요."\n    [ko, 1] 안녕하세요.\n\n--------------\n\nNote on library usage\n---------------------\n\nDISCLAIMER: this is an unofficial library using the web API of translate.google.com\nand also is not associated with Google.\n\n-  **The maximum character limit on a single text is 15k.**\n\n-  Due to limitations of the web version of google translate, this API\n   does not guarantee that the library would work properly at all times\n   (so please use this library if you don\'t care about stability).\n\n-  **Important:** If you want to use a stable API, I highly recommend you to use\n   `Google\'s official translate\n   API <https://cloud.google.com/translate/docs>`__.\n\n-  If you get HTTP 5xx error or errors like #6, it\'s probably because\n   Google has banned your client IP address.\n\n--------------\n\nVersioning\n----------\n\nThis library follows `Semantic Versioning <http://semver.org/>`__ from\nv2.0.0. Any release versioned 0.x.y is subject to backwards incompatible\nchanges at any time.\n\nSubmitting a Pull Request\n-------------------------\n\nContributions to this library are always welcome and highly encouraged\n:)\n\n1. Fork this project.\n2. Create a topic branch.\n3. Implement your feature or bug fix.\n4. Run ``pytest``.\n5. Add a test for yout feature or bug fix.\n6. Run step 4 again. If your changes are not 100% covered, go back to\n   step 5.\n7. Commit and push your changes.\n8. Submit a pull request.\n\n--------------\n\nLicense\n-------\n\nGoogletrans is licensed under the MIT License. The terms are as\nfollows:\n\n::\n\n    The MIT License (MIT)\n\n    Copyright (c) 2015 SuHun Han\n\n    Permission is hereby granted, free of charge, to any person obtaining a copy\n    of this software and associated documentation files (the "Software"), to deal\n    in the Software without restriction, including without limitation the rights\n    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n    copies of the Software, and to permit persons to whom the Software is\n    furnished to do so, subject to the following conditions:\n\n    The above copyright notice and this permission notice shall be included in all\n    copies or substantial portions of the Software.\n\n    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\n    SOFTWARE.\n\n.. |GitHub license| image:: https://img.shields.io/github/license/mashape/apistatus.svg\n   :target: http://opensource.org/licenses/MIT\n.. |travis status| image:: https://travis-ci.org/ssut/py-googletrans.svg?branch=master\n   :target: https://travis-ci.org/ssut/py-googletrans\n.. |Documentation Status| image:: https://readthedocs.org/projects/py-googletrans/badge/?version=latest\n   :target: https://readthedocs.org/projects/py-googletrans/?badge=latest\n.. |PyPI version| image:: https://badge.fury.io/py/googletrans.svg\n   :target: http://badge.fury.io/py/googletrans\n.. |Coverage Status| image:: https://coveralls.io/repos/github/ssut/py-googletrans/badge.svg\n   :target: https://coveralls.io/github/ssut/py-googletrans\n.. |Code Climate| image:: https://codeclimate.com/github/ssut/py-googletrans/badges/gpa.svg\n   :target: https://codeclimate.com/github/ssut/py-googletrans\n',
    'author': 'SuHun Han',
    'author_email': 'ssut@ssut.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/KristobalJunta/py-googletrans-html',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
